To multiply two input matrices
Line1-  Enter the number of rows in the first matrix
Line2-  Enter the number of columns in first matrix/number of rows in second matrix as the two should be equal
Line3-  Enter the number of columns in the second matrix
Line12- Enter the elemnts to be prsrnt in the first matrix
Line23- Enter the elemnts of the second matrix
Line31 -Matrix 1 is printed
Line37- Matrix 2 is printed
Line57- The multiplied matrix is printed